==> haskell-config-ini-0.2.2.0-67-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-config-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: config-ini
version: 0.2.2.0
id: config-ini-0.2.2.0-IwQzIp8TiSyJVQcicVqztG
key: config-ini-0.2.2.0-IwQzIp8TiSyJVQcicVqztG
license: BSD-3-Clause
copyright: ©2018 Getty Ritter
maintainer: Getty Ritter <config-ini@infinitenegativeutility.com>
author: Getty Ritter <config-ini@infinitenegativeutility.com>
homepage: https://github.com/aisamanra/config-ini
synopsis: A library for simple INI-based configuration files.
description:
    The @config-ini@ library is a set of small monadic languages
    for writing simple configuration languages with convenient,
    human-readable error messages.
    .
    > parseConfig :: IniParser (Text, Int, Bool)
    > parseConfig = section "NETWORK" $ do
    >   user <- field        "user"
    >   port <- fieldOf      "port" number
    >   enc  <- fieldFlagDef "encryption" True
    >   return (user, port, enc)
category: Configuration
abi: d88e02273c5d3e6d5bfe858fcf3db741
exposed: True
exposed-modules:
    Data.Ini.Config Data.Ini.Config.Bidir Data.Ini.Config.Raw
import-dirs: /usr/lib/ghc-8.4.3/site-local/config-ini-0.2.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/config-ini-0.2.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/config-ini-0.2.2.0
hs-libraries: HSconfig-ini-0.2.2.0-IwQzIp8TiSyJVQcicVqztG
depends:
    base-4.11.1.0 containers-0.5.11.0 text-1.2.3.0
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    transformers-0.5.5.0 megaparsec-6.5.0-HnTDqzdw0sJGPouOxR9YBd
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             megaparsec-6.5.0-HnTDqzdw0sJGPouOxR9YBd=4238e7005dfacdb745b68e9e59cb8c0b
haddock-interfaces: /usr/share/doc/haskell-config-ini/html/config-ini.haddock
haddock-html: /usr/share/doc/haskell-config-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-config-ini-0.2.2.0-69-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-config-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: config-ini
version: 0.2.2.0
id: config-ini-0.2.2.0-F6hcurg9zfbHnyxh91K0vx
key: config-ini-0.2.2.0-F6hcurg9zfbHnyxh91K0vx
license: BSD-3-Clause
copyright: ©2018 Getty Ritter
maintainer: Getty Ritter <config-ini@infinitenegativeutility.com>
author: Getty Ritter <config-ini@infinitenegativeutility.com>
homepage: https://github.com/aisamanra/config-ini
synopsis: A library for simple INI-based configuration files.
description:
    The @config-ini@ library is a set of small monadic languages
    for writing simple configuration languages with convenient,
    human-readable error messages.
    .
    > parseConfig :: IniParser (Text, Int, Bool)
    > parseConfig = section "NETWORK" $ do
    >   user <- field        "user"
    >   port <- fieldOf      "port" number
    >   enc  <- fieldFlagDef "encryption" True
    >   return (user, port, enc)
category: Configuration
abi: 6308c278011f7ac7fdb9011eb7535ee1
exposed: True
exposed-modules:
    Data.Ini.Config Data.Ini.Config.Bidir Data.Ini.Config.Raw
import-dirs: /usr/lib/ghc-8.4.3/site-local/config-ini-0.2.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/config-ini-0.2.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/config-ini-0.2.2.0
hs-libraries: HSconfig-ini-0.2.2.0-F6hcurg9zfbHnyxh91K0vx
depends:
    base-4.11.1.0 containers-0.5.11.0 text-1.2.3.0
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    transformers-0.5.5.0 megaparsec-6.5.0-6r6VG13rOHh1iEdbqAVDWD
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             megaparsec-6.5.0-6r6VG13rOHh1iEdbqAVDWD=a3c94d798a644b4954e8e1d552dd8707
haddock-interfaces: /usr/share/doc/haskell-config-ini/html/config-ini.haddock
haddock-html: /usr/share/doc/haskell-config-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
